@@ -1,5 +1,5 @@
 /***************************************************************************
-*   KBlocks, a falling blocks game for KDE                                 *
+*   KBlocks, a falling blocks game by KDE                                 *
 *   Copyright (C) 2010 University Freiburg <squall.leonhart.cai@gmail.com> *
 *                                                                          *
 *   This program is free software; you can redistribute it and/or modify   *
@@ -15,7 +15,7 @@
 #include "KBlocksAILog.h"
 #include "KBlocksAITypeDefine.h"
 
-#include "KBlocks_debug.h"
+#include "kblocks_ai_debug.h"
 
 #include <utility>
 #include <vector>
